@@ -5,7 +5,7 @@ from .utils import filter_possible, unique
 from .numbers import int_
 from .primitives import char, letter
 
-__all__ = ['list_', 'str_', 'str_letters']
+__all__ = ['list_', 'bytearray_', 'bytes_', 'str_', 'str_letters']
 
 
 @Arbitrary.set_for(list)
@@ -78,7 +78,7 @@ class list_(Arbitrary):
 
 @Arbitrary.set_for(bytearray)
 class bytearray_(MappedArbitrary):
-    """ Bytearray with configurable length and elements. """
+    """ Mutable bytearray with configurable length and elements. """
 
     def __init__(self, length=int_(0, 20), elements=int_(0, 255)):
         self.inner_arb = list_(length=length, elements=elements)
@@ -90,6 +90,26 @@ class bytearray_(MappedArbitrary):
         return list(s)
 
 
+class bytes_(MappedArbitrary):
+    """ Immutable bytearray with configurable length and elements.
+
+    Same as :class:`str_` in Python 2.
+    """
+
+    def __init__(self, length=int_(0, 20), elements=int_(0, 255)):
+        self.inner_arb = bytearray_(length=length, elements=elements)
+
+    def pack(self, lst):
+        return bytes(lst)
+
+    def unpack(self, s):
+        return list(s)
+
+
+if bytes is not str:
+    Arbitrary.set_for(bytes, bytes_)
+
+
 @Arbitrary.set_for(str)
 class str_(MappedArbitrary):
     """ String with configurable length and characters. """
